@@ -6,4 +6,8 @@ from . import otjigants
 from . import slau
 from . import veivletfurie
 
-__version__ = '0.1.3'
+__version__ = '0.1.4'
+__all__ = """
+    approxinterp.read_csv
+    approxinterp.polinom_chebyshev
+    """
